=====
About
=====

**WaloViz is an open-source interactive audio player with a spectrogram built-in, as a Jupyter widget or as HTML.**

| Welcome!
| WaloViz is an open source audio player with a spectrogram built-in, it was built by audio experts - for audio experts.
| To start using WaloViz right now - read our `Getting Started Guide <./getting-started.html>`_.
| WaloViz is proudly using Bokeh and the HoloViz stack for most of its features (as indicated by our name). To learn more - go to `the Bokeh website <https://bokeh.org/>`_ and `the HoloViz website <https://holoviz.org/>`_, they're great :)

Why WaloViz?
------------

| WaloViz is designed to be accessible but powerful.
| With just three lines of code it integrates seemlessly with the most popular notebook IDEs such as JupyterLab, VSCode and Google Colab.
| You can use it to view audio URLs and files but also your own processed audio tensor.
| An impressive suite of features is at your fingertips, high-level features such as overlaying your data and a built-in download button, and also low-level features for granular control like changing the colormap or sample-rate.
|
| WaloViz is open-source and proud of its community!
| With so many benefits, the real question becomes why not?

Why not?
--------

| WaloViz is in early alpha, some features are not fully tested against all platforms, and breaking changes are bound to happen.
| That's exactly why **WE NEED YOUR HELP!**
| There are 3 very simple ways in which you can help right now:

1. **Try it!** The `Getting Started Guide <./getting-started.html>`_ should get you up to speed. If there's a problem, tell us about it in a `Github Issue <https://github.com/AlonKellner/waloviz/issues/new>`_ and we'll do our best to help :) If it works and you like it - tell a friend!
2. **Consider giving us a** |:star2:| on `our Github repository <https://github.com/AlonKellner/waloviz>`_! The more stars we have, the larger our community will be, and the better WaloViz will become |:star2:|
3. **Contribute!** WaloViz is a beginner friendly project, read our `Contributing Guide <https://github.com/AlonKellner/waloviz/blob/main/CONTRIBUTING.md>`_ and take a shot at one of our `Good First Issues <https://github.com/AlonKellner/waloviz/issues?q=is%3Aissue+is%3Aopen+%3Agood-first-issue>`_!

| There might be other reasons why WaloViz might not be suited for your needs, we'd love to hear about them in a `Github Issue <https://github.com/AlonKellner/waloviz/issues/new>`_.
| We are always striving to become better, and honest criticism is how we learn best.
|
| Thank you for considering WaloViz!
